pub struct StateDiff {Show 40 fields
pub account_updates: HashMap<AccountId, AccountRecord>,
pub staking_updates: Vec<StakingUpdate>,
pub nft_updates: HashMap<[u8; 32], Option<NFTRecord>>,
pub cell_updates: Vec<CellUpdate>,
pub gas_fee: u128,
pub name_fee: u128,
pub cu_fee: u128,
pub treasury_fee: u128,
pub compute_fee_trth: u128,
pub tx_hash: [u8; 32],
pub tx_hashes: HashSet<[u8; 32]>,
pub pending_name_proposals: Vec<(String, PendingNameRegistration, AccountId, bool)>,
pub name_votes: Vec<(String, Vec<u8>, u64)>,
pub pending_token_authority_proposals: Vec<(AccountId, TokenAuthorityProposal)>,
pub token_authority_votes: Vec<(AccountId, Vec<u8>, u64)>,
pub name_renewals: Vec<(String, u64)>,
pub name_transfers: Vec<(String, AccountId)>,
pub native_transfers: Vec<(AccountId, u128)>,
pub native_debits: Vec<(AccountId, u128)>,
pub compute_escrow_credits: Vec<(AccountId, u128)>,
pub compute_escrow_debits: Vec<(AccountId, u128)>,
pub token_credits: Vec<(AccountId, AccountId, u128)>,
pub token_balance_updates: Vec<((AccountId, AccountId), u128)>,
pub staking_rewards: Vec<(AccountId, u128)>,
pub cell_credits: Vec<(AccountId, u128)>,
pub cell_debits: Vec<(AccountId, u128)>,
pub storage_deltas: HashMap<AccountId, StorageDelta>,
pub airdrop_claims: Vec<(AccountId, u64)>,
pub minted_amount: u128,
pub frozen_account_updates: Vec<((AccountId, AccountId), bool)>,
pub oracle_updates: Vec<OracleUpdate>,
pub param_updates: Vec<([u8; 32], [u8; 32])>,
pub nonce_updates: Vec<(AccountId, u64)>,
pub gas_fee_spent: u128,
pub name_fee_spent: u128,
pub compute_fee_spent: u128,
pub treasury_fee_spent: u128,
pub fee_burned: u128,
pub is_system: bool,
pub gas_breakdown: Vec<(String, u128)>,
}Fields
account_updates: HashMap<AccountId, AccountRecord>staking_updates: Vec<StakingUpdate>nft_updates: HashMap<[u8; 32], Option<NFTRecord>>cell_updates: Vec<CellUpdate>gas_fee: u128name_fee: u128cu_fee: u128treasury_fee: u128compute_fee_trth: u128tx_hash: [u8; 32]tx_hashes: HashSet<[u8; 32]>pending_name_proposals: Vec<(String, PendingNameRegistration, AccountId, bool)>name_votes: Vec<(String, Vec<u8>, u64)>name_renewals: Vec<(String, u64)>name_transfers: Vec<(String, AccountId)>native_transfers: Vec<(AccountId, u128)>native_debits: Vec<(AccountId, u128)>compute_escrow_credits: Vec<(AccountId, u128)>compute_escrow_debits: Vec<(AccountId, u128)>token_credits: Vec<(AccountId, AccountId, u128)>token_balance_updates: Vec<((AccountId, AccountId), u128)>staking_rewards: Vec<(AccountId, u128)>cell_credits: Vec<(AccountId, u128)>cell_debits: Vec<(AccountId, u128)>storage_deltas: HashMap<AccountId, StorageDelta>airdrop_claims: Vec<(AccountId, u64)>minted_amount: u128frozen_account_updates: Vec<((AccountId, AccountId), bool)>oracle_updates: Vec<OracleUpdate>param_updates: Vec<([u8; 32], [u8; 32])>nonce_updates: Vec<(AccountId, u64)>gas_fee_spent: u128name_fee_spent: u128compute_fee_spent: u128treasury_fee_spent: u128fee_burned: u128Fee revenue permanently removed during a system distribution.
This is an audit field: balances are not credited here. The amount is represented by spent fee accumulators that are intentionally not paid to validators or Staked TRTH holders.
is_system: boolgas_breakdown: Vec<(String, u128)>Trait Implementations